View Source aws_appsync (aws v0.3.1)
Link to this section Summary
Functions
Creates a cache for the GraphQL API.
Creates a unique key that you can distribute to clients who are executing your API.
Creates a
DataSource object.Creates a Function object.
Creates a
GraphqlApi object.Creates a Resolver object.
Creates a
Type object.Deletes an
ApiCache object.Deletes an API key.
Deletes a
DataSource object.Deletes a
Function.Deletes a
GraphqlApi object.Deletes a
Resolver object.Deletes a
Type object.Flushes an
ApiCache object.Retrieves an
ApiCache object.Retrieves a
DataSource object.Get a
Function.Retrieves a
GraphqlApi object.Retrieves the introspection schema for a GraphQL API.
Retrieves a
Resolver object.Retrieves the current status of a schema creation operation.
Retrieves a
Type object.Lists the API keys for a given API.
Lists the data sources for a given API.
List multiple functions.
Lists your GraphQL APIs.
Lists the resolvers for a given API and type.
List the resolvers that are associated with a specific function.
Lists the tags for a resource.
Lists the types for a given API.
Adds a new schema to your GraphQL API.
Tags a resource with user-supplied tags.
Untags a resource.
Updates the cache for the GraphQL API.
Updates an API key.
Updates a
DataSource object.Updates a
Function object.Updates a
GraphqlApi object.Updates a
Resolver object.Updates a
Type object.Link to this section Functions
DataSource object.
Creates a Function object.
GraphqlApi object.
Creates a Resolver object.
Type object.
ApiCache object.
DataSource object.
Function.
GraphqlApi object.
Resolver object.
Link to this function
delete_resolver(Client, ApiId, FieldName, TypeName, Input0, Options0)
View SourceType object.
ApiCache object.
ApiCache object.
DataSource object.
Link to this function
get_data_source(Client, ApiId, Name, QueryMap, HeadersMap, Options0)
View SourceFunction.
Link to this function
get_function(Client, ApiId, FunctionId, QueryMap, HeadersMap, Options0)
View SourceGraphqlApi object.
Link to this function
get_introspection_schema(Client, ApiId, Format, QueryMap, HeadersMap)
Link to this function
get_introspection_schema(Client, ApiId, Format, QueryMap, HeadersMap, Options0)
View SourceResolver object.
Link to this function
get_resolver(Client, ApiId, FieldName, TypeName, QueryMap, HeadersMap)
Link to this function
get_resolver(Client, ApiId, FieldName, TypeName, QueryMap, HeadersMap, Options0)
Link to this function
get_schema_creation_status(Client, ApiId, QueryMap, HeadersMap, Options0)
View SourceType object.
Link to this function
get_type(Client, ApiId, TypeName, Format, QueryMap, HeadersMap, Options0)
View SourceLists the API keys for a given API.
API keys are deleted automatically 60 days after they expire. However, they may still be included in the response until they have actually been deleted. You can safely callDeleteApiKey to manually delete a key before it's automatically deleted.
Link to this function
list_resolvers(Client, ApiId, TypeName, QueryMap, HeadersMap, Options0)
Link to this function
list_resolvers_by_function(Client, ApiId, FunctionId, QueryMap, HeadersMap)
Link to this function
list_resolvers_by_function(Client, ApiId, FunctionId, QueryMap, HeadersMap, Options0)
Link to this function
list_tags_for_resource(Client, ResourceArn, QueryMap, HeadersMap, Options0)
View SourceAdds a new schema to your GraphQL API.
This operation is asynchronous. Use to determine when it has completed.Updates an API key.
The key can be updated while it is not deleted.DataSource object.
Function object.
GraphqlApi object.
Resolver object.
Link to this function
update_resolver(Client, ApiId, FieldName, TypeName, Input0, Options0)
View SourceType object.