View Source aws_forecast (aws v0.3.1)
Link to this section Summary
Functions
Creates an Amazon Forecast dataset.
Creates a dataset group, which holds a collection of related datasets.
Imports your training data to an Amazon Forecast dataset.
Creates a forecast for each item in the TARGET_TIME_SERIES dataset that was used to train the predictor.
Exports a forecast created by the CreateForecast operation to your Amazon Simple Storage Service (Amazon S3) bucket.
Creates an Amazon Forecast predictor.
Exports backtest forecasts and accuracy metrics generated by the CreatePredictor operation.
Deletes an Amazon Forecast dataset that was created using the CreateDataset operation.
Deletes a dataset group created using the CreateDatasetGroup operation.
Deletes a dataset import job created using the CreateDatasetImportJob operation.
Deletes a forecast created using the CreateForecast operation.
Deletes a forecast export job created using the CreateForecastExportJob operation.
Deletes a predictor created using the CreatePredictor operation.
Describes an Amazon Forecast dataset created using the CreateDataset operation.
Describes a dataset group created using the CreateDatasetGroup operation.
Describes a dataset import job created using the CreateDatasetImportJob operation.
Describes a forecast created using the CreateForecast operation.
Describes a forecast export job created using the CreateForecastExportJob operation.
Describes a predictor created using the CreatePredictor operation.
Describes a predictor backtest export job created using the CreatePredictorBacktestExportJob operation.
Provides metrics on the accuracy of the models that were trained by the CreatePredictor operation.
Returns a list of dataset groups created using the CreateDatasetGroup operation.
Returns a list of dataset import jobs created using the CreateDatasetImportJob operation.
Returns a list of datasets created using the CreateDataset operation.
Returns a list of forecast export jobs created using the CreateForecastExportJob operation.
Returns a list of forecasts created using the CreateForecast operation.
Returns a list of predictor backtest export jobs created using the CreatePredictorBacktestExportJob operation.
Returns a list of predictors created using the CreatePredictor operation.
Stops a resource.
Associates the specified tags to a resource with the specified resourceArn.
Replaces the datasets in a dataset group with the specified datasets.
Link to this section Functions
Creates an Amazon Forecast dataset.
The information about the dataset that you provide helps Forecast understand how to consume the data for model training. This includes the following:
DataFrequency- How frequently your historical time-series data is collected.DomainandDatasetType- Each dataset has an associated dataset domain and a type within the domain. Amazon Forecast provides a list of predefined domains and types within each domain. For each unique dataset domain and type within the domain, Amazon Forecast requires your data to include a minimum set of predefined fields.Schema- A schema specifies the fields in the dataset, including the field name and data type.
After creating a dataset, you import your training data into it and add the dataset to a dataset group. You use the dataset group to create a predictor. For more information, see howitworks-datasets-groups.
To get a list of all your datasets, use the ListDatasets operation.
For example Forecast datasets, see the Amazon Forecast Sample GitHub repository.
TheStatus of a dataset must be ACTIVE before you can import training data. Use the DescribeDataset operation to get the status.
Creates a dataset group, which holds a collection of related datasets.
You can add datasets to the dataset group when you create the dataset group, or later by using the UpdateDatasetGroup operation.
After creating a dataset group and adding datasets, you use the dataset group when you create a predictor. For more information, see howitworks-datasets-groups.
To get a list of all your datasets groups, use the ListDatasetGroups operation.
Status of a dataset group must be ACTIVE before you can use the dataset group to create a predictor. To get the status, use the DescribeDatasetGroup operation.
Imports your training data to an Amazon Forecast dataset.
You provide the location of your training data in an Amazon Simple Storage Service (Amazon S3) bucket and the Amazon Resource Name (ARN) of the dataset that you want to import the data to.
You must specify a DataSource object that includes an AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the data, as Amazon Forecast makes a copy of your data and processes it in an internal AWS system. For more information, see aws-forecast-iam-roles.
The training data must be in CSV format. The delimiter must be a comma (,).
You can specify the path to a specific CSV file, the S3 bucket, or to a folder in the S3 bucket. For the latter two cases, Amazon Forecast imports all files up to the limit of 10,000 files.
Because dataset imports are not aggregated, your most recent dataset import is the one that is used when training a predictor or generating a forecast. Make sure that your most recent dataset import contains all of the data you want to model off of, and not just the new data collected since the previous import.
To get a list of all your dataset import jobs, filtered by specified criteria, use theListDatasetImportJobs operation.
Creates a forecast for each item in the TARGET_TIME_SERIES dataset that was used to train the predictor.
This is known as inference. To retrieve the forecast for a single item at low latency, use the operation. To export the complete forecast into your Amazon Simple Storage Service (Amazon S3) bucket, use the CreateForecastExportJob operation.
The range of the forecast is determined by the ForecastHorizon value, which you specify in the CreatePredictor request. When you query a forecast, you can request a specific date range within the forecast.
To get a list of all your forecasts, use the ListForecasts operation.
The forecasts generated by Amazon Forecast are in the same time zone as the dataset that was used to create the predictor.
For more information, see howitworks-forecast.
Status of the forecast must be ACTIVE before you can query or export the forecast. Use the DescribeForecast operation to get the status.
Exports a forecast created by the CreateForecast operation to your Amazon Simple Storage Service (Amazon S3) bucket.
The forecast file name will match the following conventions:
ForecastExportJobName_ExportTimestamp_PartNumber
where the ExportTimestamp component is in Java SimpleDateFormat (yyyy-MM-ddTHH-mm-ssZ).
You must specify a DataDestination object that includes an AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the Amazon S3 bucket. For more information, see aws-forecast-iam-roles.
For more information, see howitworks-forecast.
To get a list of all your forecast export jobs, use the ListForecastExportJobs operation.
Status of the forecast export job must be ACTIVE before you can access the forecast in your Amazon S3 bucket. To get the status, use the DescribeForecastExportJob operation.
Creates an Amazon Forecast predictor.
In the request, provide a dataset group and either specify an algorithm or let Amazon Forecast choose an algorithm for you using AutoML. If you specify an algorithm, you also can override algorithm-specific hyperparameters.
Amazon Forecast uses the algorithm to train a predictor using the latest version of the datasets in the specified dataset group. You can then generate a forecast using the CreateForecast operation.
To see the evaluation metrics, use the GetAccuracyMetrics operation.
You can specify a featurization configuration to fill and aggregate the data fields in the TARGET_TIME_SERIES dataset to improve model training. For more information, see FeaturizationConfig.
For RELATED_TIME_SERIES datasets, CreatePredictor verifies that the DataFrequency specified when the dataset was created matches the ForecastFrequency. TARGET_TIME_SERIES datasets don't have this restriction. Amazon Forecast also verifies the delimiter and timestamp format. For more information, see howitworks-datasets-groups.
By default, predictors are trained and evaluated at the 0.1 (P10), 0.5 (P50), and 0.9 (P90) quantiles. You can choose custom forecast types to train and evaluate your predictor by setting the ForecastTypes.
AutoML
If you want Amazon Forecast to evaluate each algorithm and choose the one that minimizes the objective function, set PerformAutoML to true. The objective function is defined as the mean of the weighted losses over the forecast types. By default, these are the p10, p50, and p90 quantile losses. For more information, see EvaluationResult.
When AutoML is enabled, the following properties are disallowed:
AlgorithmArnHPOConfigPerformHPOTrainingParameters
To get a list of all of your predictors, use the ListPredictors operation.
Status of the predictor must be ACTIVE, signifying that training has completed. To get the status, use the DescribePredictor operation.
Exports backtest forecasts and accuracy metrics generated by the CreatePredictor operation.
Two folders containing CSV files are exported to your specified S3 bucket.
The export file names will match the following conventions:
<ExportJobName>_<ExportTimestamp>_<PartNumber>.csv
The ExportTimestamp component is in Java SimpleDate format (yyyy-MM-ddTHH-mm-ssZ).
You must specify a DataDestination object that includes an Amazon S3 bucket and an AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the Amazon S3 bucket. For more information, see aws-forecast-iam-roles.
Status of the export job must be ACTIVE before you can access the export in your Amazon S3 bucket. To get the status, use the DescribePredictorBacktestExportJob operation.
Deletes an Amazon Forecast dataset that was created using the CreateDataset operation.
You can only delete datasets that have a status of ACTIVE or CREATE_FAILED. To get the status use the DescribeDataset operation.
Deletes a dataset group created using the CreateDatasetGroup operation.
You can only delete dataset groups that have a status of ACTIVE, CREATE_FAILED, or UPDATE_FAILED. To get the status, use the DescribeDatasetGroup operation.
Deletes a dataset import job created using the CreateDatasetImportJob operation.
ACTIVE or CREATE_FAILED. To get the status, use the DescribeDatasetImportJob operation.
Deletes a forecast created using the CreateForecast operation.
You can delete only forecasts that have a status of ACTIVE or CREATE_FAILED. To get the status, use the DescribeForecast operation.
Deletes a forecast export job created using the CreateForecastExportJob operation.
ACTIVE or CREATE_FAILED. To get the status, use the DescribeForecastExportJob operation.
Deletes a predictor created using the CreatePredictor operation.
ACTIVE or CREATE_FAILED. To get the status, use the DescribePredictor operation.
Describes an Amazon Forecast dataset created using the CreateDataset operation.
In addition to listing the parameters specified in the CreateDataset request, this operation includes the following dataset properties:
CreationTimeLastModificationTimeStatus
Describes a dataset group created using the CreateDatasetGroup operation.
In addition to listing the parameters provided in the CreateDatasetGroup request, this operation includes the following properties:
DatasetArns- The datasets belonging to the group.CreationTimeLastModificationTimeStatus
Describes a dataset import job created using the CreateDatasetImportJob operation.
In addition to listing the parameters provided in the CreateDatasetImportJob request, this operation includes the following properties:
CreationTimeLastModificationTimeDataSizeFieldStatisticsStatusMessage- If an error occurred, information about the error.
Describes a forecast created using the CreateForecast operation.
In addition to listing the properties provided in the CreateForecast request, this operation lists the following properties:
DatasetGroupArn- The dataset group that provided the training data.CreationTimeLastModificationTimeStatusMessage- If an error occurred, information about the error.
Describes a forecast export job created using the CreateForecastExportJob operation.
In addition to listing the properties provided by the user in the CreateForecastExportJob request, this operation lists the following properties:
CreationTimeLastModificationTimeStatusMessage- If an error occurred, information about the error.
Describes a predictor created using the CreatePredictor operation.
In addition to listing the properties provided in the CreatePredictor request, this operation lists the following properties:
DatasetImportJobArns- The dataset import jobs used to import training data.AutoMLAlgorithmArns- If AutoML is performed, the algorithms that were evaluated.CreationTimeLastModificationTimeStatusMessage- If an error occurred, information about the error.
Describes a predictor backtest export job created using the CreatePredictorBacktestExportJob operation.
In addition to listing the properties provided by the user in the CreatePredictorBacktestExportJob request, this operation lists the following properties:
CreationTimeLastModificationTimeStatusMessage(if an error occurred)
Provides metrics on the accuracy of the models that were trained by the CreatePredictor operation.
Use metrics to see how well the model performed and to decide whether to use the predictor to generate a forecast. For more information, see Predictor Metrics.
This operation generates metrics for each backtest window that was evaluated. The number of backtest windows (NumberOfBacktestWindows) is specified using the EvaluationParameters object, which is optionally included in the CreatePredictor request. If NumberOfBacktestWindows isn't specified, the number defaults to one.
The parameters of the filling method determine which items contribute to the metrics. If you want all items to contribute, specify zero. If you want only those items that have complete data in the range being evaluated to contribute, specify nan. For more information, see FeaturizationMethod.
Status of the predictor must be ACTIVE, signifying that training has completed. To get the status, use the DescribePredictor operation.
Returns a list of dataset groups created using the CreateDatasetGroup operation.
DescribeDatasetGroup operation.
Returns a list of dataset import jobs created using the CreateDatasetImportJob operation.
DescribeDatasetImportJob operation. You can filter the list by providing an array of Filter objects.
Returns a list of datasets created using the CreateDataset operation.
DescribeDataset operation.
Returns a list of forecast export jobs created using the CreateForecastExportJob operation.
DescribeForecastExportJob operation. You can filter the list using an array of Filter objects.
Returns a list of forecasts created using the CreateForecast operation.
DescribeForecast operation. You can filter the list using an array of Filter objects.
Returns a list of predictor backtest export jobs created using the CreatePredictorBacktestExportJob operation.
This operation returns a summary for each backtest export job. You can filter the list using an array of Filter objects.
DescribePredictorBacktestExportJob operation.
Returns a list of predictors created using the CreatePredictor operation.
DescribePredictor operation. You can filter the list using an array of Filter objects.
Stops a resource.
The resource undergoes the following states: CREATE_STOPPING and CREATE_STOPPED. You cannot resume a resource once it has been stopped.
This operation can be applied to the following resources (and their corresponding child resources):
Dataset Import Job
Predictor Job
Forecast Job
Forecast Export Job
Predictor Backtest Export Job
Associates the specified tags to a resource with the specified resourceArn.
Replaces the datasets in a dataset group with the specified datasets.
TheStatus of the dataset group must be ACTIVE before you can use the dataset group to create a predictor. Use the DescribeDatasetGroup operation to get the status.