View Source aws_identitystore (aws v0.3.1)
Link to this section Summary
Functions
Retrieves the group metadata and attributes from
GroupId in an identity store.Retrieves the user metadata and attributes from
UserId in an identity store.Lists the attribute name and value of the group that you specified in the search.
Lists the attribute name and value of the user that you specified in the search.
Link to this section Functions
GroupId in an identity store.
UserId in an identity store.
Lists the attribute name and value of the group that you specified in the search.
We only supportDisplayName as a valid filter attribute path currently, and filter is required. This API returns minimum attributes, including GroupId and group DisplayName in the response.
Lists the attribute name and value of the user that you specified in the search.
We only supportUserName as a valid filter attribute path currently, and filter is required. This API returns minimum attributes, including UserId and UserName in the response.