View Source aws_imagebuilder (aws v0.3.1)
Link to this section Summary
Functions
CancelImageCreation cancels the creation of Image.
Creates a new container recipe.
Creates a new distribution configuration.
Creates a new image.
Creates a new image pipeline.
Creates a new image recipe.
Creates a new infrastructure configuration.
Applies a policy to a component.
Applies a policy to a container image.
Applies a policy to an image.
Applies a policy to an image recipe.
Updates a new distribution configuration.
Updates a new image pipeline.
Updates a new infrastructure configuration.
Link to this section Functions
CancelImageCreation cancels the creation of Image.
This operation can only be used on images in a non-terminal state.Creates a new container recipe.
Container recipes define how images are configured, tested, and assessed.Creates a new distribution configuration.
Distribution configurations define and configure the outputs of your pipeline.Creates a new image.
This request will create a new image along with all of the configured output resources defined in the distribution configuration.Creates a new image pipeline.
Image pipelines enable you to automate the creation and distribution of images.Creates a new image recipe.
Image recipes define how images are configured, tested, and assessed.Creates a new infrastructure configuration.
An infrastructure configuration defines the environment in which your image will be built and tested.get_component(Client, ComponentBuildVersionArn, QueryMap, HeadersMap)
View Sourceget_component(Client, ComponentBuildVersionArn, QueryMap, HeadersMap, Options0)
View Sourceget_component_policy(Client, ComponentArn, QueryMap, HeadersMap, Options0)
View Sourceget_container_recipe(Client, ContainerRecipeArn, QueryMap, HeadersMap)
View Sourceget_container_recipe(Client, ContainerRecipeArn, QueryMap, HeadersMap, Options0)
View Sourceget_container_recipe_policy(Client, ContainerRecipeArn, QueryMap, HeadersMap)
View Sourceget_container_recipe_policy(Client, ContainerRecipeArn, QueryMap, HeadersMap, Options0)
View Sourceget_distribution_configuration(Client, DistributionConfigurationArn)
View Sourceget_distribution_configuration(Client, DistributionConfigurationArn, QueryMap, HeadersMap)
View Sourceget_distribution_configuration(Client, DistributionConfigurationArn, QueryMap, HeadersMap, Options0)
View Sourceget_image(Client, ImageBuildVersionArn, QueryMap, HeadersMap, Options0)
View Sourceget_image_pipeline(Client, ImagePipelineArn, QueryMap, HeadersMap)
View Sourceget_image_pipeline(Client, ImagePipelineArn, QueryMap, HeadersMap, Options0)
View Sourceget_image_policy(Client, ImageArn, QueryMap, HeadersMap, Options0)
View Sourceget_image_recipe(Client, ImageRecipeArn, QueryMap, HeadersMap, Options0)
View Sourceget_image_recipe_policy(Client, ImageRecipeArn, QueryMap, HeadersMap)
View Sourceget_image_recipe_policy(Client, ImageRecipeArn, QueryMap, HeadersMap, Options0)
View Sourceget_infrastructure_configuration(Client, InfrastructureConfigurationArn)
View Sourceget_infrastructure_configuration(Client, InfrastructureConfigurationArn, QueryMap, HeadersMap)
View Sourceget_infrastructure_configuration(Client, InfrastructureConfigurationArn, QueryMap, HeadersMap, Options0)
View Sourcelist_tags_for_resource(Client, ResourceArn, QueryMap, HeadersMap, Options0)
View SourceApplies a policy to a component.
We recommend that you call the RAM API CreateResourceShare to share resources. If you call the Image Builder APIPutComponentPolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy in order for the resource to be visible to all principals with whom the resource is shared.
Applies a policy to a container image.
We recommend that you call the RAM API CreateResourceShare (https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html) to share resources. If you call the Image Builder APIPutContainerImagePolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy (https://docs.aws.amazon.com/ram/latest/APIReference/API_PromoteResourceShareCreatedFromPolicy.html) in order for the resource to be visible to all principals with whom the resource is shared.
Applies a policy to an image.
We recommend that you call the RAM API CreateResourceShare to share resources. If you call the Image Builder APIPutImagePolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy in order for the resource to be visible to all principals with whom the resource is shared.
Applies a policy to an image recipe.
We recommend that you call the RAM API CreateResourceShare to share resources. If you call the Image Builder APIPutImageRecipePolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy in order for the resource to be visible to all principals with whom the resource is shared.
Updates a new distribution configuration.
Distribution configurations define and configure the outputs of your pipeline.Updates a new image pipeline.
Image pipelines enable you to automate the creation and distribution of images.Updates a new infrastructure configuration.
An infrastructure configuration defines the environment in which your image will be built and tested.